@@ -86,7 +86,7 @@
 #define KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED
-#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
+#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x54600
+#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
@@ -117,5 +117,6 @@
 #endif
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4_##minor(text)
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION(major, minor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KGLOBALACCELPRIVATE_EXPORT_H */
